Given a deletion and its sequence context, categorize it.
Canonicalize1DEL(context, del.seq, pos, trace = 0)The deleted sequence plus ample surrounding
sequence on each side (at least as long as del.seq).
The deleted sequence in context.
The position of del.sequence in context.
If > 0 cat information how the computation is carried out.
A string that is the canonical representation of the given deletion type